@@ -11,13 +11,21 @@ from apigee.types import Struct
 from apigee.verbose import common_verbose_options
 
 
-@click.group(help='The proxy APIs let you perform operations on API proxies, such as create, delete, update, and deploy.')
+@click.group(
+    help='The proxy APIs let you perform operations on API proxies, such as create, delete, update, and deploy.'
+)
 def apis():
     pass
 
 
-def _delete_api_proxy_revision(username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).delete_api_proxy_revision(name, revision_number).text
+def _delete_api_proxy_revision(
+    username, password, mfa_secret, token, zonename, org, profile, name, revision_number, **kwargs
+):
+    return (
+        Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .delete_api_proxy_revision(name, revision_number)
+        .text
+    )
 
 
 @apis.command(
@@ -33,7 +41,19 @@ def delete_revision(*args, **kwargs):
 
 
 def _deploy_api_proxy_revision(
-    username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, delay=0, override=False, **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    environment,
+    revision_number,
+    delay=0,
+    override=False,
+    **kwargs,
 ):
     return (
         Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
@@ -64,11 +84,17 @@ def deploy_revision(*args, **kwargs):
     console.echo(_deploy_api_proxy_revision(*args, **kwargs))
 
 
-def _delete_undeployed_revisions(username, password, mfa_secret, token, zonename, org, profile, name, save_last=0, dry_run=False, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).delete_undeployed_revisions(name, save_last=save_last, dry_run=dry_run)
+def _delete_undeployed_revisions(
+    username, password, mfa_secret, token, zonename, org, profile, name, save_last=0, dry_run=False, **kwargs
+):
+    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).delete_undeployed_revisions(
+        name, save_last=save_last, dry_run=dry_run
+    )
 
 
-@apis.command(help='Deletes all undeployed revisions of an API proxy and all policies, resources, endpoints, and revisions associated with it.')
+@apis.command(
+    help='Deletes all undeployed revisions of an API proxy and all policies, resources, endpoints, and revisions associated with it.'
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -79,7 +105,20 @@ def clean(*args, **kwargs):
     _delete_undeployed_revisions(*args, **kwargs)
 
 
-def _export_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, revision_number, fs_write=True, output_file=None, **kwargs):
+def _export_api_proxy(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    revision_number,
+    fs_write=True,
+    output_file=None,
+    **kwargs,
+):
     return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).export_api_proxy(
         name, revision_number, fs_write=True, output_file=output_file if output_file else f'{name}.zip'
     )
@@ -111,7 +150,9 @@ def get(*args, **kwargs):
     console.echo(_get_api_proxy(*args, **kwargs))
 
 
-def _list_api_proxies(username, password, mfa_secret, token, zonename, org, profile, prefix=None, format='json', **kwargs):
+def _list_api_proxies(
+    username, password, mfa_secret, token, zonename, org, profile, prefix=None, format='json', **kwargs
+):
     return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).list_api_proxies(prefix=prefix)
 
 
@@ -139,8 +180,14 @@ def list_revisions(*args, **kwargs):
     console.echo(_list_api_proxy_revisions(*args, **kwargs))
 
 
-def _undeploy_api_proxy_revision(username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).undeploy_api_proxy_revision(name, environment, revision_number).text
+def _undeploy_api_proxy_revision(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs
+):
+    return (
+        Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .undeploy_api_proxy_revision(name, environment, revision_number)
+        .text
+    )
 
 
 @apis.command(help='Undeploys an API proxy revision from an environment.')
@@ -154,8 +201,14 @@ def undeploy_revision(*args, **kwargs):
     console.echo(_undeploy_api_proxy_revision(*args, **kwargs))
 
 
-def _force_undeploy_api_proxy_revision(username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org).force_undeploy_api_proxy_revision(name, environment, revision_number).text
+def _force_undeploy_api_proxy_revision(
+    username, password, mfa_secret, token, zonename, org, profile, name, environment, revision_number, **kwargs
+):
+    return (
+        Apis(gen_auth(username, password, mfa_secret, token, zonename), org)
+        .force_undeploy_api_proxy_revision(name, environment, revision_number)
+        .text
+    )
 
 
 @apis.command(help='Force the undeployment of the API proxy that is partially deployed.')
@@ -187,12 +240,18 @@ def _pull(
     basepath=None,
     **kwargs,
 ):
-    return Apis(gen_auth(username, password, mfa_secret, token, zonename), org, revision_number, environment, work_tree=work_tree).pull(
-        name, force=force, prefix=prefix, basepath=basepath
-    )
+    return Apis(
+        gen_auth(username, password, mfa_secret, token, zonename),
+        org,
+        revision_number,
+        environment,
+        work_tree=work_tree,
+    ).pull(name, force=force, prefix=prefix, basepath=basepath)
 
 
-@apis.command(help='Downloads an API proxy revision, along with any referenced key/value maps, target servers and caches into the current working directory.')
+@apis.command(
+    help='Downloads an API proxy revision, along with any referenced key/value maps, target servers and caches into the current working directory.'
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -201,13 +260,29 @@ def _pull(
 @click.option('-e', '--environment', help='environment', required=True)
 @click.option('--work-tree', help='set the path to the working tree (defaults to current working directory)')
 @click.option('--force/--no-force', '-f/-F', default=False, help='force write files')
-@click.option('--prefix', help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.')
+@click.option(
+    '--prefix', help='prefix to prepend to names. WARNING: this is not foolproof. make sure to review the changes.'
+)
 @click.option('-b', '--basepath', help='set default basepath in apiproxy/proxies/default.xml')
 def pull(*args, **kwargs):
     _pull(*args, **kwargs)
 
 
-def _deploy(username, password, mfa_secret, token, zonename, org, profile, name, directory, import_only, seamless_deploy, environment, **kwargs):
+def _deploy(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    directory,
+    import_only,
+    seamless_deploy,
+    environment,
+    **kwargs,
+):
     return deploy_tool(
         Struct(
             username=username,
