@@ -15,8 +15,14 @@ def apps():
     pass
 
 
-def _create_developer_app(username, password, mfa_secret, token, zonename, org, profile, name, developer, body, **kwargs):
-    return Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None).create_developer_app(developer, body).text
+def _create_developer_app(
+    username, password, mfa_secret, token, zonename, org, profile, name, developer, body, **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None)
+        .create_developer_app(developer, body)
+        .text
+    )
 
 
 @apps.command(
@@ -33,7 +39,9 @@ def create(*args, **kwargs):
 
 
 def _delete_developer_app(username, password, mfa_secret, token, zonename, org, profile, name, developer, **kwargs):
-    return Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_developer_app(developer).text
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_developer_app(developer).text
+    )
 
 
 @apps.command(help='Deletes a developer app.')
@@ -46,7 +54,20 @@ def delete(*args, **kwargs):
     console.echo(_delete_developer_app(*args, **kwargs))
 
 
-def _create_empty_developer_app(username, password, mfa_secret, token, zonename, org, profile, name, developer, display_name="", callback_url="", **kwargs):
+def _create_empty_developer_app(
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    name,
+    developer,
+    display_name="",
+    callback_url="",
+    **kwargs
+):
     return (
         Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
         .create_empty_developer_app(developer, display_name=display_name, callback_url=callback_url)
@@ -74,8 +95,14 @@ def create_empty(*args, **kwargs):
     console.echo(_create_empty_developer_app(*args, **kwargs))
 
 
-def _get_developer_app_details(username, password, mfa_secret, token, zonename, org, profile, name, developer, **kwargs):
-    return Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_developer_app_details(developer).text
+def _get_developer_app_details(
+    username, password, mfa_secret, token, zonename, org, profile, name, developer, **kwargs
+):
+    return (
+        Apps(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_developer_app_details(developer)
+        .text
+    )
 
 
 @apps.command(
@@ -91,7 +118,19 @@ def get(*args, **kwargs):
 
 
 def _list_developer_apps(
-    username, password, mfa_secret, token, zonename, org, profile, developer, prefix=None, expand=False, count=1000, startkey="", **kwargs
+    username,
+    password,
+    mfa_secret,
+    token,
+    zonename,
+    org,
+    profile,
+    developer,
+    prefix=None,
+    expand=False,
+    count=1000,
+    startkey="",
+    **kwargs
 ):
     return Apps(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_developer_apps(
         developer, prefix=prefix, expand=expand, count=count, startkey=startkey
@@ -119,7 +158,10 @@ def _list_developer_apps(
     help='Limits the list to the number you specify. The limit is 100. Use with the startKey parameter to provide more targeted filtering.',
 )
 @click.option(
-    '--startkey', default="", show_default=True, help='To filter the keys that are returned, enter the name of a developer app that the list will start with.'
+    '--startkey',
+    default="",
+    show_default=True,
+    help='To filter the keys that are returned, enter the name of a developer app that the list will start with.',
 )
 def list(*args, **kwargs):
     console.echo(_list_developer_apps(*args, **kwargs))
@@ -192,7 +234,14 @@ def _create_a_consumer_key_and_secret(
 @click.option('--key-suffix', default=None, help="")
 @click.option('--key-delimiter', default='-', help='separates consumerKey and key suffix with a delimiter.')
 # @click.option("products", "--products", multiple=True, default=[], help="A list of API products to be associated with the app's credentials")
-@click.option('products', '--products', metavar='LIST', cls=OptionEatAll, default=[], help="A list of API products to be associated with the app's credentials")
+@click.option(
+    'products',
+    '--products',
+    metavar='LIST',
+    cls=OptionEatAll,
+    default=[],
+    help="A list of API products to be associated with the app's credentials",
+)
 def create_creds(*args, **kwargs):
     # click.echo(kwargs.get('products'))
     # import sys;sys.exit(1)
@@ -211,6 +260,8 @@ def _restore_app(username, password, mfa_secret, token, zonename, org, profile,
 @common_auth_options
 @common_silent_options
 @common_verbose_options
-@click.option('-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True)
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
 def restore(*args, **kwargs):
     _restore_app(*args, **kwargs)
