@@ -15,7 +15,7 @@ from apigee.exceptions import InvalidApisError, NotYetImplementedError
 from apigee.keyvaluemaps.keyvaluemaps import Keyvaluemaps
 from apigee.permissions.permissions import Permissions
 from apigee.targetservers.targetservers import Targetservers
-from apigee.types import Struct
+from apigee.types import APIS, Struct, empty_snapshot
 from apigee.userroles.userroles import Userroles
 from apigee.utils import (extract_zip, resolve_target_directory, touch,
                           write_file)
@@ -23,18 +23,21 @@ from apigee.utils import (extract_zip, resolve_target_directory, touch,
 
 class Backups:
 
-    APIS = ('apis', 'keyvaluemaps', 'targetservers', 'caches', 'developers', 'apiproducts', 'apps', 'userroles')
     SNAPSHOTS_DIRECTORY_NAME = 'snapshots'
 
-    def __init__(self, auth, org_name, target_directory, prefix=None, fs_write=False, apis=None, environments=['test', 'prod']):
+    def __init__(
+        self, auth, org_name, target_directory, prefix=None, fs_write=False, apis=APIS, environments=['test', 'prod']
+    ):
         self.auth = auth
         self.org_name = org_name
         self.target_directory = resolve_target_directory(target_directory)
         self.prefix = prefix
         self.fs_write = fs_write
-        self.apis = apis or APIS
+        if not isinstance(apis, set):
+            apis = set(apis)
+        self.apis = apis
         self.environments = environments
-        self.snapshot_data = Struct(apis={}, keyvaluemaps={}, targetservers={}, caches={}, developers=[], apps={}, apiproducts=[], userroles=[])
+        self.snapshot_data = empty_snapshot()
         self.snapshot_size = 0
         self.progress_bar = None
 
@@ -51,13 +54,15 @@ class Backups:
         if not value:
             raise InvalidApisError
         for t in value:
-            if t not in self.APIS:
+            if t not in APIS:
                 raise InvalidApisError
         self._apis = value
 
     def _progress_callback(self, desc=''):
         if not isinstance(self.progress_bar, tqdm):
-            self.progress_bar = tqdm(total=self.snapshot_size, unit='files', bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}', leave=False)
+            self.progress_bar = tqdm(
+                total=self.snapshot_size, unit='files', bar_format='{l_bar}{bar:32}{r_bar}{bar:-10b}', leave=False
+            )
         if desc:
             self.progress_bar.set_description(desc)
         self.progress_bar.update(1)
@@ -67,7 +72,13 @@ class Backups:
             self.snapshot_data.apis[api] = Apis(self.auth, self.org_name, None).get_api_proxy(api).json()
             write_file(
                 self.snapshot_data.apis[api],
-                str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'apis' / (api + '.json')),
+                str(
+                    Path(self.target_directory)
+                    / self.org_name
+                    / self.SNAPSHOTS_DIRECTORY_NAME
+                    / 'apis'
+                    / (api + '.json')
+                ),
                 fs_write=self.fs_write,
             )
         return self.snapshot_data.apis
@@ -78,25 +89,36 @@ class Backups:
                 output_dir = str(Path(self.target_directory) / self.org_name / 'apis' / api / revision)
                 output_zip = str(Path(output_dir) / (api + '.zip'))
                 try:
-                    Apis(self.auth, self.org_name, None).export_api_proxy(api, revision, fs_write=True, output_file=output_zip)
+                    Apis(self.auth, self.org_name, None).export_api_proxy(
+                        api, revision, fs_write=True, output_file=output_zip
+                    )
                     extract_zip(output_zip, output_dir)
                     os.remove(output_zip)
                 except HTTPError as e:
-                    console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for API Proxy ({api}, revision {revision})')
+                    console.echo(
+                        f'Ignoring {type(e).__name__} {e.response.status_code} error for API Proxy ({api}, revision {revision})'
+                    )
             self._progress_callback(desc='APIs')
         return self.snapshot_data.apis
 
     def download_keyvaluemaps_snapshot(self):
         for environment in self.environments:
             try:
-                self.snapshot_data.keyvaluemaps[environment] = Keyvaluemaps(self.auth, self.org_name, None).list_keyvaluemaps_in_an_environment(
-                    environment, prefix=self.prefix, format='dict'
-                )
+                self.snapshot_data.keyvaluemaps[environment] = Keyvaluemaps(
+                    self.auth, self.org_name, None
+                ).list_keyvaluemaps_in_an_environment(environment, prefix=self.prefix, format='dict')
             except HTTPError:
                 self.snapshot_data.keyvaluemaps[environment] = []
             write_file(
                 self.snapshot_data.keyvaluemaps[environment],
-                str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'keyvaluemaps' / environment / 'keyvaluemaps.json'),
+                str(
+                    Path(self.target_directory)
+                    / self.org_name
+                    / self.SNAPSHOTS_DIRECTORY_NAME
+                    / 'keyvaluemaps'
+                    / environment
+                    / 'keyvaluemaps.json'
+                ),
                 fs_write=self.fs_write,
             )
         return self.snapshot_data.keyvaluemaps
@@ -107,7 +129,9 @@ class Backups:
                 try:
                     write_file(
                         Keyvaluemaps(self.auth, self.org_name, kvm).get_keyvaluemap_in_an_environment(environment).text,
-                        str(Path(self.target_directory) / self.org_name / 'keyvaluemaps' / environment / (kvm + '.json')),
+                        str(
+                            Path(self.target_directory) / self.org_name / 'keyvaluemaps' / environment / (kvm + '.json')
+                        ),
                         fs_write=True,
                     )
                 except HTTPError as e:
@@ -118,14 +142,21 @@ class Backups:
     def download_targetservers_snapshot(self):
         for environment in self.environments:
             try:
-                self.snapshot_data.targetservers[environment] = Targetservers(self.auth, self.org_name, None).list_targetservers_in_an_environment(
-                    environment, prefix=self.prefix, format='dict'
-                )
+                self.snapshot_data.targetservers[environment] = Targetservers(
+                    self.auth, self.org_name, None
+                ).list_targetservers_in_an_environment(environment, prefix=self.prefix, format='dict')
             except HTTPError:
                 self.snapshot_data.targetservers[environment] = []
             write_file(
                 self.snapshot_data.targetservers[environment],
-                str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'targetservers' / environment / 'targetservers.json'),
+                str(
+                    Path(self.target_directory)
+                    / self.org_name
+                    / self.SNAPSHOTS_DIRECTORY_NAME
+                    / 'targetservers'
+                    / environment
+                    / 'targetservers.json'
+                ),
                 fs_write=self.fs_write,
             )
         return self.snapshot_data.targetservers
@@ -136,25 +167,40 @@ class Backups:
                 try:
                     write_file(
                         Targetservers(self.auth, self.org_name, targetserver).get_targetserver(environment).text,
-                        str(Path(self.target_directory) / self.org_name / 'targetservers' / environment / (targetserver + '.json')),
+                        str(
+                            Path(self.target_directory)
+                            / self.org_name
+                            / 'targetservers'
+                            / environment
+                            / (targetserver + '.json')
+                        ),
                         fs_write=True,
                     )
                 except HTTPError as e:
-                    console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for TargetServer ({targetserver})')
+                    console.echo(
+                        f'Ignoring {type(e).__name__} {e.response.status_code} error for TargetServer ({targetserver})'
+                    )
                 self._progress_callback(desc='TargetServers')
         return self.snapshot_data.targetservers
 
     def download_caches_snapshot(self):
         for environment in self.environments:
             try:
-                self.snapshot_data.caches[environment] = Caches(self.auth, self.org_name, None).list_caches_in_an_environment(
-                    environment, prefix=self.prefix, format='dict'
-                )
+                self.snapshot_data.caches[environment] = Caches(
+                    self.auth, self.org_name, None
+                ).list_caches_in_an_environment(environment, prefix=self.prefix, format='dict')
             except HTTPError:
                 self.snapshot_data.caches[environment] = []
             write_file(
                 self.snapshot_data.caches[environment],
-                str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'caches' / environment / 'caches.json'),
+                str(
+                    Path(self.target_directory)
+                    / self.org_name
+                    / self.SNAPSHOTS_DIRECTORY_NAME
+                    / 'caches'
+                    / environment
+                    / 'caches.json'
+                ),
                 fs_write=self.fs_write,
             )
         return self.snapshot_data.caches
@@ -174,10 +220,18 @@ class Backups:
         return self.snapshot_data.caches
 
     def download_developers_snapshot(self):
-        self.snapshot_data.developers = Developers(self.auth, self.org_name, None).list_developers(prefix=self.prefix, format='dict')
+        self.snapshot_data.developers = Developers(self.auth, self.org_name, None).list_developers(
+            prefix=self.prefix, format='dict'
+        )
         write_file(
             self.snapshot_data.developers,
-            str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'developers' / 'developers.json'),
+            str(
+                Path(self.target_directory)
+                / self.org_name
+                / self.SNAPSHOTS_DIRECTORY_NAME
+                / 'developers'
+                / 'developers.json'
+            ),
             fs_write=self.fs_write,
         )
         return self.snapshot_data.developers
@@ -196,10 +250,18 @@ class Backups:
         return self.snapshot_data.developers
 
     def download_apiproducts_snapshot(self):
-        self.snapshot_data.apiproducts = Apiproducts(self.auth, self.org_name, None).list_api_products(prefix=self.prefix, format='dict')
+        self.snapshot_data.apiproducts = Apiproducts(self.auth, self.org_name, None).list_api_products(
+            prefix=self.prefix, format='dict'
+        )
         write_file(
             self.snapshot_data.apiproducts,
-            str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'apiproducts' / 'apiproducts.json'),
+            str(
+                Path(self.target_directory)
+                / self.org_name
+                / self.SNAPSHOTS_DIRECTORY_NAME
+                / 'apiproducts'
+                / 'apiproducts.json'
+            ),
             fs_write=self.fs_write,
         )
         return self.snapshot_data.apiproducts
@@ -213,20 +275,32 @@ class Backups:
                     fs_write=self.fs_write,
                 )
             except HTTPError as e:
-                console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for API Product ({apiproduct})')
+                console.echo(
+                    f'Ignoring {type(e).__name__} {e.response.status_code} error for API Product ({apiproduct})'
+                )
             self._progress_callback(desc='API Products')
         return self.snapshot_data.apiproducts
 
     def download_apps_snapshot(self, expand=False, count=1000, startkey=""):
         self.snapshot_data.apps = Apps(self.auth, self.org_name, None).list_apps_for_all_developers(
-            Developers(self.auth, self.org_name, None).list_developers(prefix=None, expand=expand, count=count, startkey=startkey, format='dict'),
+            Developers(self.auth, self.org_name, None).list_developers(
+                prefix=None, expand=expand, count=count, startkey=startkey, format='dict'
+            ),
             prefix=self.prefix,
             format='dict',
         )
         self.snapshot_data.apps = {k: v for k, v in self.snapshot_data.apps.items() if v}
         for app, details in self.snapshot_data.apps.items():
             write_file(
-                details, str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'apps' / (app + '.json')), fs_write=self.fs_write
+                details,
+                str(
+                    Path(self.target_directory)
+                    / self.org_name
+                    / self.SNAPSHOTS_DIRECTORY_NAME
+                    / 'apps'
+                    / (app + '.json')
+                ),
+                fs_write=self.fs_write,
             )
         return self.snapshot_data.apps
 
@@ -240,17 +314,27 @@ class Backups:
                         fs_write=self.fs_write,
                     )
                 except HTTPError as e:
-                    console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for Developer App ({app})')
+                    console.echo(
+                        f'Ignoring {type(e).__name__} {e.response.status_code} error for Developer App ({app})'
+                    )
                 self._progress_callback(desc='Developer Apps')
         return self.snapshot_data.apps
 
     def download_userroles_snapshot(self):
         self.snapshot_data.userroles = Userroles(self.auth, self.org_name, None).list_user_roles().json()
         if self.prefix:
-            self.snapshot_data.userroles = [role for role in self.snapshot_data.userroles if role.startswith(self.prefix)]
+            self.snapshot_data.userroles = [
+                role for role in self.snapshot_data.userroles if role.startswith(self.prefix)
+            ]
         write_file(
             self.snapshot_data.userroles,
-            str(Path(self.target_directory) / self.org_name / self.SNAPSHOTS_DIRECTORY_NAME / 'userroles' / 'userroles.json'),
+            str(
+                Path(self.target_directory)
+                / self.org_name
+                / self.SNAPSHOTS_DIRECTORY_NAME
+                / 'userroles'
+                / 'userroles.json'
+            ),
             fs_write=self.fs_write,
         )
         return self.snapshot_data.userroles
@@ -258,27 +342,48 @@ class Backups:
     def _get_users_for_a_role(self, role_name):
         return Userroles(self.auth, self.org_name, role_name).get_users_for_a_role().text
 
+    @staticmethod
+    def _sort_lists_in_permissions(resource_permissions):
+        for i in range(len(resource_permissions.get('resourcePermission'))):
+            resource_permissions['resourcePermission'][i]['permissions'].sort()
+        return resource_permissions
+
     def _get_permissions(self, role_name):
-        return Permissions(self.auth, self.org_name, role_name).get_permissions(formatted=True, format='text')
+        return json.dumps(
+            Backups._sort_lists_in_permissions(
+                Permissions(self.auth, self.org_name, role_name).get_permissions(formatted=True, format='json')
+            ),
+            indent=2,
+        )
+
+    def _download_users_for_a_role(self, role_name):
+        try:
+            write_file(
+                self._get_users_for_a_role(role_name),
+                str(Path(self.target_directory) / self.org_name / 'userroles' / role_name / 'users.json'),
+                fs_write=self.fs_write,
+            )
+        except HTTPError as e:
+            console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({role_name}) users')
+
+    def _download_resource_permissions(self, role_name):
+        try:
+            write_file(
+                self._get_permissions(role_name),
+                str(
+                    Path(self.target_directory) / self.org_name / 'userroles' / role_name / 'resource_permissions.json'
+                ),
+                fs_write=self.fs_write,
+            )
+        except HTTPError as e:
+            console.echo(
+                f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({role_name}) resource permissions'
+            )
 
     def download_userroles(self):
-        for userrole in self.snapshot_data.userroles:
-            try:
-                write_file(
-                    self._get_users_for_a_role(userrole),
-                    str(Path(self.target_directory) / self.org_name / 'userroles' / userrole / 'users.json'),
-                    fs_write=self.fs_write,
-                )
-            except HTTPError as e:
-                console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({userrole}) users')
-            try:
-                write_file(
-                    self._get_permissions(userrole),
-                    str(Path(self.target_directory) / self.org_name / 'userroles' / userrole / 'resource_permissions.json'),
-                    fs_write=self.fs_write,
-                )
-            except HTTPError as e:
-                console.echo(f'Ignoring {type(e).__name__} {e.response.status_code} error for User Role ({userrole}) resource permissions')
+        for role_name in self.snapshot_data.userroles:
+            self._download_users_for_a_role(role_name)
+            self._download_resource_permissions(role_name)
             self._progress_callback(desc='User Roles')
         return self.snapshot_data.userroles
 
