@@ -13,8 +13,14 @@ def maskconfigs():
     pass
 
 
-def _create_data_masks_for_an_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name).create_data_masks_for_an_api_proxy(body).text
+def _create_data_masks_for_an_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs
+):
+    return (
+        Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .create_data_masks_for_an_api_proxy(body)
+        .text
+    )
 
 
 @maskconfigs.command(
@@ -29,8 +35,14 @@ def create_api(*args, **kwargs):
     console.echo(_create_data_masks_for_an_api_proxy(*args, **kwargs))
 
 
-def _delete_data_masks_for_an_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, maskconfig_name, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_data_masks_for_an_api_proxy(maskconfig_name).text
+def _delete_data_masks_for_an_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, maskconfig_name, **kwargs
+):
+    return (
+        Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .delete_data_masks_for_an_api_proxy(maskconfig_name)
+        .text
+    )
 
 
 @maskconfigs.command(help='Delete a data mask for an API proxy.')
@@ -43,8 +55,14 @@ def delete_api(*args, **kwargs):
     console.echo(_delete_data_masks_for_an_api_proxy(*args, **kwargs))
 
 
-def _get_data_mask_details_for_an_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, maskconfig_name, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name).get_data_mask_details_for_an_api_proxy(maskconfig_name).text
+def _get_data_mask_details_for_an_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, maskconfig_name, **kwargs
+):
+    return (
+        Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .get_data_mask_details_for_an_api_proxy(maskconfig_name)
+        .text
+    )
 
 
 @maskconfigs.command(help='Get the details for a data mask for an API proxy.')
@@ -58,7 +76,11 @@ def get_api(*args, **kwargs):
 
 
 def _list_data_masks_for_an_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name).list_data_masks_for_an_api_proxy().text
+    return (
+        Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .list_data_masks_for_an_api_proxy()
+        .text
+    )
 
 
 @maskconfigs.command(help='List all data masks for an API proxy.')
@@ -71,7 +93,11 @@ def list_api(*args, **kwargs):
 
 
 def _list_data_masks_for_an_organization(username, password, mfa_secret, token, zonename, org, profile, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, None).list_data_masks_for_an_organization().text
+    return (
+        Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, None)
+        .list_data_masks_for_an_organization()
+        .text
+    )
 
 
 @maskconfigs.command(help='List all data masks for an organization.')
@@ -82,8 +108,12 @@ def list(*args, **kwargs):
     console.echo(_list_data_masks_for_an_organization(*args, **kwargs))
 
 
-def _push_data_masks_for_an_api_proxy(username, password, mfa_secret, token, zonename, org, profile, name, file, **kwargs):
-    return Maskconfigs(gen_auth(username, password, mfa_secret, token, zonename), org, name).push_data_masks_for_an_api_proxy(file)
+def _push_data_masks_for_an_api_proxy(
+    username, password, mfa_secret, token, zonename, org, profile, name, file, **kwargs
+):
+    return Maskconfigs(
+        gen_auth(username, password, mfa_secret, token, zonename), org, name
+    ).push_data_masks_for_an_api_proxy(file)
 
 
 @maskconfigs.command(help='Push data mask for an API proxy to Apigee. This will create/update a data mask.')
@@ -91,6 +121,8 @@ def _push_data_masks_for_an_api_proxy(username, password, mfa_secret, token, zon
 @common_silent_options
 @common_verbose_options
 @click.option('-n', '--name', help='API proxy name', required=True)
-@click.option('-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True)
+@click.option(
+    '-f', '--file', type=click.Path(exists=True, dir_okay=False, file_okay=True, resolve_path=False), required=True
+)
 def push(*args, **kwargs):
     _push_data_masks_for_an_api_proxy(*args, **kwargs)
