@@ -17,7 +17,11 @@ def userroles():
 
 
 def _add_a_user_to_a_role(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_a_user_to_a_role(user_email).text
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .add_a_user_to_a_role(user_email)
+        .text
+    )
 
 
 @userroles.command(help='Add a user to a role.')
@@ -30,8 +34,14 @@ def add_user(*args, **kwargs):
     console.echo(_add_a_user_to_a_role(*args, **kwargs))
 
 
-def _add_permissions_for_a_resource_to_a_user_role(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_permissions_for_a_resource_to_a_user_role(body).text
+def _add_permissions_for_a_resource_to_a_user_role(
+    username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .add_permissions_for_a_resource_to_a_user_role(body)
+        .text
+    )
 
 
 @userroles.command(help='Add Permissions for Resource to a Role')
@@ -44,8 +54,14 @@ def add_permissions(*args, **kwargs):
     console.echo(_add_permissions_for_a_resource_to_a_user_role(*args, **kwargs))
 
 
-def _add_permissions_for_multiple_resources_to_a_user_role(username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).add_permissions_for_multiple_resources_to_a_user_role(body).text
+def _add_permissions_for_multiple_resources_to_a_user_role(
+    username, password, mfa_secret, token, zonename, org, profile, name, body, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .add_permissions_for_multiple_resources_to_a_user_role(body)
+        .text
+    )
 
 
 @userroles.command(help='Adds multiple permissions to multiple resources simultaneously.')
@@ -58,8 +74,14 @@ def add_permissions_multiple(*args, **kwargs):
     console.echo(_add_permissions_for_multiple_resources_to_a_user_role(*args, **kwargs))
 
 
-def _create_a_user_role_in_an_organization(username, password, mfa_secret, token, zonename, org, profile, names, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, names).create_a_user_role_in_an_organization().text
+def _create_a_user_role_in_an_organization(
+    username, password, mfa_secret, token, zonename, org, profile, names, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, names)
+        .create_a_user_role_in_an_organization()
+        .text
+    )
 
 
 @userroles.command(help='Creates one or more user roles in an organization.')
@@ -71,8 +93,14 @@ def create(*args, **kwargs):
     console.echo(_create_a_user_role_in_an_organization(*args, **kwargs))
 
 
-def _delete_a_permission_for_a_resource(username, password, mfa_secret, token, zonename, org, profile, name, permission, resource_path, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_a_permission_for_a_resource(permission, resource_path).text
+def _delete_a_permission_for_a_resource(
+    username, password, mfa_secret, token, zonename, org, profile, name, permission, resource_path, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .delete_a_permission_for_a_resource(permission, resource_path)
+        .text
+    )
 
 
 @userroles.command(
@@ -88,11 +116,19 @@ def delete_permission(*args, **kwargs):
     console.echo(_delete_a_permission_for_a_resource(*args, **kwargs))
 
 
-def _delete_resource_from_permissions(username, password, mfa_secret, token, zonename, org, profile, name, resource_path, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).delete_resource_from_permissions(resource_path).text
+def _delete_resource_from_permissions(
+    username, password, mfa_secret, token, zonename, org, profile, name, resource_path, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .delete_resource_from_permissions(resource_path)
+        .text
+    )
 
 
-@userroles.command(help='Removes all permissions for a resource for the role specified. Permissions are case sensitive.')
+@userroles.command(
+    help='Removes all permissions for a resource for the role specified. Permissions are case sensitive.'
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -128,7 +164,9 @@ def get(*args, **kwargs):
     console.echo(_get_a_role(*args, **kwargs))
 
 
-def _get_resource_permissions_for_a_specific_role(username, password, mfa_secret, token, zonename, org, profile, name, resource_path="", **kwargs):
+def _get_resource_permissions_for_a_specific_role(
+    username, password, mfa_secret, token, zonename, org, profile, name, resource_path="", **kwargs
+):
     return (
         Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
         .get_resource_permissions_for_a_specific_role(resource_path=resource_path)
@@ -160,7 +198,11 @@ def get_users(*args, **kwargs):
 
 
 def _list_permissions_for_a_resource(username, password, mfa_secret, token, zonename, org, profile, name, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).list_permissions_for_a_resource().text
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .list_permissions_for_a_resource()
+        .text
+    )
 
 
 @userroles.command(help='Gets permissions for all resources associated with a user role.')
@@ -185,8 +227,14 @@ def list(*args, **kwargs):
     console.echo(_list_user_roles(*args, **kwargs))
 
 
-def _remove_user_membership_in_role(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).remove_user_membership_in_role(user_email).text
+def _remove_user_membership_in_role(
+    username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .remove_user_membership_in_role(user_email)
+        .text
+    )
 
 
 @userroles.command(help='Remove user membership in role.')
@@ -209,7 +257,9 @@ def _verify_a_user_roles_permission_on_a_specific_RBAC_resource(
     )
 
 
-@userroles.command(help="Verifies that a user role's permission on a specific resource exists. Returns a value of true or false.")
+@userroles.command(
+    help="Verifies that a user role's permission on a specific resource exists. Returns a value of true or false."
+)
 @common_auth_options
 @common_verbose_options
 @common_silent_options
@@ -220,8 +270,14 @@ def verify_permission(*args, **kwargs):
     console.echo(_verify_a_user_roles_permission_on_a_specific_RBAC_resource(*args, **kwargs))
 
 
-def _verify_user_role_membership(username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs):
-    return Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name).verify_user_role_membership(user_email).text
+def _verify_user_role_membership(
+    username, password, mfa_secret, token, zonename, org, profile, name, user_email, **kwargs
+):
+    return (
+        Userroles(gen_auth(username, password, mfa_secret, token, zonename), org, name)
+        .verify_user_role_membership(user_email)
+        .text
+    )
 
 
 @userroles.command(help='Verify user role membership.')
